package com.brynhild.common.utils;

import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.TimeZone;

public class TimeUtil {
    private static SimpleDateFormat timeStringFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    private static SimpleDateFormat timeNumberStringFormat = new SimpleDateFormat("yyyyMMddHHmmss");


    private TimeUtil() {
        final TimeZone timeZone = TimeZone.getTimeZone("GMT+8");
        TimeZone.setDefault(timeZone);
    }

    public static String getCurrentTimeString() {
        return timeStringFormat.format(new Date());
    }

    public static String getCurrentTimeNumberString() {
        return timeNumberStringFormat.format(new Date());
    }

    public static String convertToTimeString(String timeNumberString) {
        try {
            return timeStringFormat.format(timeNumberStringFormat.parse(timeNumberString));
        } catch (Exception e) {
            return null;
        }
    }

    public static String convertToTimeNumberString(String timeString) {
        try {
            return timeNumberStringFormat.format(timeStringFormat.parse(timeString));
        } catch (Exception e) {
            return null;
        }
    }

    public static Date getMonthDate(Date startDate, int month) {
        LocalDateTime localDateTime = startDate.toInstant()
                .atZone(ZoneId.systemDefault())
                .toLocalDateTime().plusMonths(month);
        Date date = Date.from(localDateTime.atZone(ZoneId.systemDefault()).toInstant());
        return date;
    }

    public static Date getMonthDate(int month) {
        return getMonthDate(new Date(), month);
    }

    public static String getMonthDateString(int month) {
        return timeStringFormat.format(getMonthDate(month));
    }

    public static Long getTimeDifference(String time) {
        try {
            Date now = new Date();
            Date originDate = timeStringFormat.parse(time);
            return now.getTime() - originDate.getTime();
        } catch (Exception e) {
            e.printStackTrace();
            return 0L;
        }
    }

    public static String renewValidity(String origin, int month) {
        try {
            Date now = new Date();
            Date originDate = timeStringFormat.parse(origin);
            Date newDate = null;
            if (originDate.getTime() <= now.getTime()) {
                newDate = getMonthDate(now, month);
            } else {
                newDate = getMonthDate(originDate, month);
            }
            return timeStringFormat.format(newDate);
        } catch (Exception e) {
            e.printStackTrace();
            return origin;
        }
    }

    public static boolean expire(String time) {
        try {
            Date now = new Date();
            Date origin = timeStringFormat.parse(time);
            return origin.getTime() < now.getTime();
        } catch (Exception e) {
            e.printStackTrace();
            return true;
        }
    }
}
